@@ -5,6 +5,7 @@ import unittest
 import subprocess
 from pygridspot import *
 
+
 class V1(unittest.TestCase):
     def setUp(self):
         cwd = os.getcwd()
@@ -12,8 +13,9 @@ class V1(unittest.TestCase):
 
         print "Starting", server_path
         self.serv = subprocess.Popen(['python', server_path])
-        time.sleep(1)
-    
+        print "Started"
+        time.sleep(2)
+
     def tearDown(self):
         print "Stopping test server"
 
@@ -21,10 +23,13 @@ class V1(unittest.TestCase):
         subprocess.call("ps -ef | grep python.*v1_server | grep -v grep | awk "
                         "'{print $2}' | xargs -I {} kill -9 {}", shell=True)
 
-    def test_list(self):
-        g = Gridspot(api_key='testkey', target_url_base='http://localhost:5000')
+    def test_requests(self):
+        g = Gridspot(
+            api_key='testkey', target_url_base='http://localhost:5000')
 
         il = g.get_instances()
 
         self.assertEquals(len(il.new), 1)
         self.assertEquals(il.new[0].instance_id, "inst_CP2WrQi2WIS4iheyAVkQYw")
+
+        g.stop_instance("inst_CP2WrQi2WIS4iheyAVkQYw")
